﻿<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
   xmlns:svg="http://www.w3.org/2000/svg"
   xmlns:xhtml="http://www.w3.org/1999/xhtml"
   xmlns:xlink="http://www.w3.org/1999/xlink">
  
  <xsl:output method="html" encoding="UTF-8"/>

    <xsl:include href="./attributes.xsl" />

<xsl:template match="/">

  <html>
   
   <head>
     <title>[XIPA] - Extensible International Phonetic Alphabet</title>
      <link rel="stylesheet" type="text/css" href="./data/styles.css" />
         
<!--###############################   SCRIPTS   ################################# -->
     
     <script type="text/javascript" src="./data/scripts/jquery-1.11.3.min.js"></script>
     <script type="text/javascript" src="./data/scripts/onclickSwitcher.js"></script>
     <script type="text/javascript" src="./data/scripts/insertAtCursor.js"></script>
     <script type="text/javascript" src="./data/scripts/tooltip.js"></script>

   </head>

     <body xsl:use-attribute-sets="body.style">
       
       <script>
			$( document ).ready(function() {
			// switch to unicode transcription mode at beginning
			$('#button_transcribe').click();
			// activate tooltip on pageload
			$('#button_tooltip').click();
			// testing browser compatibility, disable audio button if no Audio API present (old IE and the like)
			if (typeof AudioContext == "undefined" &amp;&amp; typeof webkitAudioContext == "undefined") {
				// disable audio button, as Web Audio API is not supported
				$('#button_sound').prop("disabled", true);
			}
			
			$( "body" ).keydown(function( event ) {
				
				if (event.which == '13' &amp;&amp; $('#button_transcribe').is(":checked") &amp;&amp; $('#button_sound').prop('disabled') == false) {
				  event.preventDefault();
					$('#button_sound').focus();
					$('#button_sound').click();
					$( "body" ).keyup(function( event ) {
						if (event.which == '13') {
							$('#button_transcribe').click();
							$( 'body' ).unbind("keyup");
						}
					});
				}
			});
			
			});
       </script>

<!-- ###########################  CONSONANTS (PULMONIC) ######################### -->

<div xsl:use-attribute-sets="div.consonants" id="consonants">
<caption xsl:use-attribute-sets="caption.style"><h3>Consonants (Pulmonic)</h3></caption>
  <table id="con" xsl:use-attribute-sets="table.consonants">
    <tr xsl:use-attribute-sets="space.adjustment">
       <th xsl:use-attribute-sets="th.manner_and_place"></th>
       <th xsl:use-attribute-sets="th.place">Bilabial</th>
       <th xsl:use-attribute-sets="th.place.large">Labiodental</th>
       <th xsl:use-attribute-sets="th.place">Dental</th>
       <th xsl:use-attribute-sets="th.place">Alveolar</th>
       <th xsl:use-attribute-sets="th.place.large">Postalveolar</th>
       <th xsl:use-attribute-sets="th.place">Retroflex</th>
       <th xsl:use-attribute-sets="th.place">Palatal</th>
       <th xsl:use-attribute-sets="th.place">Velar</th>
       <th xsl:use-attribute-sets="th.place">Uvular</th>
       <th xsl:use-attribute-sets="th.place.large">Pharyngeal</th>
       <th xsl:use-attribute-sets="th.place">Glottal</th>
     </tr>

     <tr manner="plosive">
       <th xsl:use-attribute-sets="th.manner">Plosive</th>
         <xsl:call-template name="Consonants">
           <xsl:with-param name="manner" select="'plosive'"/>
         </xsl:call-template>
     </tr>
     
     <tr manner="nasal">
       <th xsl:use-attribute-sets="th.manner">Nasal</th>
          <xsl:call-template name="Consonants">
            <xsl:with-param name="manner" select="'nasal'"/>
          </xsl:call-template>
     </tr>
     
     <tr manner="trill">
       <th xsl:use-attribute-sets="th.manner">Trill</th>
          <xsl:call-template name="Consonants">
            <xsl:with-param name="manner" select="'trill'"/>
          </xsl:call-template>
     </tr>
     
     <tr manner="taporflap">
       <th xsl:use-attribute-sets="th.manner">Tap or Flap</th>
          <xsl:call-template name="Consonants">
            <xsl:with-param name="manner" select="'tap or flap'"/>
          </xsl:call-template>
     </tr>
     
     <tr manner="fricative">
       <th xsl:use-attribute-sets="th.manner">Fricative</th>
          <xsl:call-template name="Consonants">
            <xsl:with-param name="manner" select="'fricative'"/>
          </xsl:call-template>
     </tr> 
     
     <tr manner="lateralfricative">
       <th xsl:use-attribute-sets="th.manner">Lateral Fricative</th>
          <xsl:call-template name="Consonants">
            <xsl:with-param name="manner" select="'lateral fricative'"/>
          </xsl:call-template>
     </tr> 
     
     <tr manner="approximant">
       <th xsl:use-attribute-sets="th.manner">Approximant</th>
          <xsl:call-template name="Consonants">
            <xsl:with-param name="manner" select="'approximant'"/>
          </xsl:call-template>
     </tr> 
     
     <tr manner="lateralapproximant">
       <th xsl:use-attribute-sets="th.manner">Lateral Approximant</th>
          <xsl:call-template name="Consonants">
            <xsl:with-param name="manner" select="'lateral approximant'"/>
          </xsl:call-template>
     </tr> 
     <th class="inf" xsl:use-attribute-sets="info.style">
        Where symbols appear in pairs, the one to the right represents a voiced consonant (a rounded vowel). Shaded areas denote articulations judged impossible.
     </th>
   </table>
</div>     

<!-- #############################  OTHER SYMBOLS ############################### -->

<div xsl:use-attribute-sets="div.other_symbols" id="other_symbols">
<caption xsl:use-attribute-sets="caption.style"><h3>Other Symbols</h3></caption>
  <table id="oth" xsl:use-attribute-sets="table.other_symbols">
     <xsl:call-template name="OtherSymbols"/>
   </table>
</div>

<!-- #############################  USER INTERFACE  ############################ -->

<div style="width: 75%; float: left;" class="box">

<form method="post" id="transcription_selector" style="width: 100%">
  <label title="Show additional information on mouseover">
    <input type="checkbox"
      id="button_tooltip"
      value="Show"
      onclick="toggleTooltip();"/> Tooltip
   </label>
   <label title="Play audio file (hold down the enter key to switch from transcription mode to play mode)">
    <input type="radio"
      id="button_sound"
      name="output"
      value="Play"
      onclick="switchToAudio();"
    /> Play Sound
    </label>  
   <label title="Paste characters on mouseclick into the text field">
    <input type="radio"
      id="button_transcribe"
      name="output"
      value="Transcribe"
      onclick="switchToTranscription();"
    /> Transcribe in 
   </label>
    <label>
      <select id="transcription_method" onchange="switchToTranscription()" title="Select a transcription method">
        <option value="unicode" 
                selected="selected">
                Unicode
        </option>
        <option value="unicode_hex" 
                title="Transcribe in hexadecimal Unicode entities">
                Unicode (entities)
        </option>
        <option value="tex" 
                title="Input macro names in the normal LaTeX text environment">
                LaTeX
        </option>
        <option value="tex2" 
                title="Shortcut input method embedded in IPA environment (see the manual for further explanation)">
                LaTeX (short)
        </option>
        <option value="praat"
                title="Shortcuts for drawing phonetic symbols in Praat (TextGridEditor and Picture window)">
                Praat
        </option>
      </select> 
    </label>
</form>
 
</div>
       
<!-- #########################  IPA CODE INPUT ELEMENT ########################### -->

<form name="formular" 
      method="POST"
      spellcheck="false"
      translate="no"
      autocomplete="on"
      xsl:use-attribute-sets="formular.form">
      <p>
        <input id="IPAInput" 
               type="text" 
               name="formel"
               xsl:use-attribute-sets="ipa.input.style">
        </input>
      </p>
</form>

<!-- ###########################  SVG CHART VOWELS  ############################## -->

<div style="float:left" id="vowels">
<caption xsl:use-attribute-sets="caption.style"><h3>Vowels</h3></caption> 
  <svg 
    xmlns="http://www.w3.org/2000/svg" 
    version="1.1"
    width="465" 
    height="280"
    viewBox="0 0 465 280">

    <!--############# MAIN FRAME ##############-->   
    <g id="description">

      <!--DESCRIPTION TEXT-->
      <text x="83" y="10" text-anchor="middle" xsl:use-attribute-sets="vowels.text">Front</text>
      <text x="260" y="10" text-anchor="middle" xsl:use-attribute-sets="vowels.text">Central</text>
      <text x="435" y="10" text-anchor="middle" xsl:use-attribute-sets="vowels.text">Back</text>
      <text x="0" y="37" xsl:use-attribute-sets="vowels.text">Close</text>
      <text x="0" y="117" xsl:use-attribute-sets="vowels.text">Close-mid</text>
      <text x="0" y="194" xsl:use-attribute-sets="vowels.text">Open-mid</text>
      <text x="0" y="270" xsl:use-attribute-sets="vowels.text">Open</text>

      <!--########### QUADRILATERAL #############-->
      <g id="quadrilateral" transform="translate(84,34)">
 
        <!--VERTICAL LINES-->
        <path d="M0   0 176   234" stroke-width=".3"/>
        <path d="M176 0 263.5 234" stroke-width=".3"/>
        <path d="M351 0 351   234" stroke-width=".3"/>
        
        <!--HORIZONTAL LINES-->
        <path d="M0   0   351 0" stroke-width=".3"/>
        <path d="M59  78  351 78" stroke-width=".3"/>
        <path d="M117 156 351 156" stroke-width=".3"/>
        <path d="M176 234 351 234" stroke-width=".3"/>
        
        <!--########### ANCHORPOINTS ##############-->
        <!--CLOSE-->
        <circle cx="0" cy="0" r="2.5"/>
        <circle cx="176" cy="0" r="2.5"/>
        <circle cx="351" cy="0" r="2.5"/>
        
        <!--NEAR-CLOSE-->
        <circle cx="59" cy="39" r="0"/>
        <circle cx="351" cy="39" r="0"/>
        
        <!--CLOSE-MID-->
        <circle cx="59" cy="78" r="2.5"/>
        <circle cx="205" cy="78" r="2.5"/>
        <circle cx="351" cy="78" r="2.5"/>
        
        <!--MID-->
        <circle cx="219.5" cy="117" r="0"/>
        
        <!--OPEN-MID-->
        <circle cx="117" cy="156" r="2.5"/>
        <circle cx="234" cy="156" r="2.5"/>
        <circle cx="351" cy="156" r="2.5"/>
        
        <!--NEAR-OPEN-->
        <circle cx="147" cy="195" r="0"/>
        <circle cx="249" cy="195" r="0"/> 
        
        <!--OPEN-->
        <circle cx="176" cy="234" r="2.5"/>
        <circle cx="351" cy="234" r="2.5"/>       

        <!--########### VOWELSPACE ##############-->
        <g id="vowelspace">
          
          <xsl:call-template name="Vowels"/>
 
        </g>
      </g>
    </g>
  </svg>
</div>
       
<!-- ###########################  DIACRITICS ################################### -->

<div xsl:use-attribute-sets="div.diacritics" id="diacritics">
<caption xsl:use-attribute-sets="caption.style"><h3>Diacritics</h3></caption>
  <table id="dia1" xsl:use-attribute-sets="table.diacritics1">
     <xsl:call-template name="Diacritics1"/>
   </table>
  <table id="dia2" xsl:use-attribute-sets="table.diacritics2">
     <xsl:call-template name="Diacritics2"/>
   </table>
</div>

<!-- ##########################  SUPRASEGMENTALS ############################### -->

<div xsl:use-attribute-sets="div.suprasegmentals" id="suprasegmentals">
<caption xsl:use-attribute-sets="caption.style"><h3>Suprasegmentals</h3></caption>
  <table id="sup" xsl:use-attribute-sets="table.suprasegmentals">
     <xsl:call-template name="Suprasegmentals"/>
   </table>
</div>

<!-- ###########################  TONES AND WORD ACENTS ######################### -->

       <div xsl:use-attribute-sets="div.accents" id="accents">
<caption xsl:use-attribute-sets="caption.style"><h3>Tones &amp; Word Accents</h3></caption>
   <table id="acc1" xsl:use-attribute-sets="table.accents">
     <xsl:call-template name="Accents1"/>
   </table>
  <table id="acc2" xsl:use-attribute-sets="table.accents">
     <xsl:call-template name="Accents2"/>
   </table>
</div>

<!-- #########################  CONSONANTS NON-PULMONIC ######################### -->

<div xsl:use-attribute-sets="div.consonants_np" id="consonants_np">
<caption xsl:use-attribute-sets="caption.style"><h3>Consonants (non-pulmonic)</h3></caption>
  <table id="clic" xsl:use-attribute-sets="table.consonants_np">
   <caption xsl:use-attribute-sets="subcaption.style"><h4>Clicks</h4></caption>
     <xsl:call-template name="Clicks"/>
   </table>
  <table id="impl" xsl:use-attribute-sets="table.consonants_np">
   <caption xsl:use-attribute-sets="subcaption.style"><h4>Implosives</h4></caption>
     <xsl:call-template name="Implosives"/>
   </table>
  <table id="ejec" xsl:use-attribute-sets="table.consonants_np">
   <caption xsl:use-attribute-sets="subcaption.style"><h4>Ejectives</h4></caption>
     <xsl:call-template name="Ejectives"/>
   </table>
</div>

<!-- ###############################  FOOTER  ################################## -->
    
 <div class="footer">
   
   <hr class="rule"></hr>
   
   <p>This project is free and open-source, licensed under a <a href="data/documents/license.html" target="_blank">BSD 2-Clause</a> License
     <br />
     Copyright &#xa9; 2015 Sebastian Musche
   </p>
   
 </div>
       
<!-- ############################################################################ -->                                                                                                                                     
<!-- #########################  !!! XSL:APPLY-TEMPLATES !!! ##################### -->
<!-- ############################################################################ -->
      
       <xsl:apply-templates select="sound"/>
  
     </body>
   </html>
  
</xsl:template>

<!-- ############################################################################ -->
<!-- ###############################           ################################## -->
<!-- ############################### TEMPLATES ################################## -->
<!-- ###############################           ################################## -->
<!-- ############################################################################ -->
 
 
<!-- ############################################################################ -->
<!-- ######################## PLOT VOWEL SYMBOLS IN SVG ######################### -->
<!-- ############################################################################ -->

  <xsl:template name="Plot_Symbol">
    <xsl:param name="name"/>
    
      <!-- VISIBLE PART - POPULATE ALL SVG ELEMENTS WITH UNICODE SYMBOLS -->
      <xsl:value-of select="$name/unicode/text()"/>

  </xsl:template>

<!-- ############################################################################ -->
<!-- ########################### PLOT UNICODE SYMBOLS ########################### -->
<!-- ############################################################################ -->

<xsl:template name="Transcribe">
  <xsl:param name="name"/>
  
    
    <xsl:call-template name="Add_metadata">
      <xsl:with-param name="name" select="$name"></xsl:with-param>
    </xsl:call-template> 
  
     <!-- VISIBLE PART - POPULATE ALL CELLS WITH UNICODE SYMBOLS -->
     <xsl:value-of select="$name/unicode"/>

</xsl:template>

<!-- ############################################################################ -->
<!-- #############################  VARIABLES  ################################## -->
<!-- ############################################################################ -->

<!-- #######################  TRANSFORM TO UPPERCASE  ########################## -->

<xsl:variable name="lowercase" select="'abcdefghijklmnopqrstuvwxyz'"/>
<xsl:variable name="uppercase" select="'ABCDEFGHIJKLMNOPQRSTUVWXYZ'"/>


<!-- ############################################################################ -->
<!-- ###########################  TEMPLATE VOWELS  ############################## -->
<!-- ############################################################################ -->

<xsl:template name="Vowels">
  
  <xsl:for-each select="/ipa/sound[@type='vowel' and class!='emp']">
   <xsl:variable name="setname" select="concat('int-',name/cardinal/text())" />
   <xsl:variable name="set" select="document('./vowels.xsl')/*/xsl:attribute-set[@name = $setname]" />
    <circle xmlns="http://www.w3.org/2000/svg" class='pos'>
       <xsl:for-each select="$set/xsl:attribute">
         <xsl:attribute name="r">13</xsl:attribute>
         <xsl:attribute name="c{@name}">
           <xsl:value-of select="." />
         </xsl:attribute>
       </xsl:for-each>
         <xsl:call-template name="Transcribe">
           <xsl:with-param name="name" select="./name"></xsl:with-param>
         </xsl:call-template>
     </circle>
    
     <text xmlns="http://www.w3.org/2000/svg">
       <xsl:for-each select="$set/xsl:attribute">
         <xsl:attribute name="pointer-events">none</xsl:attribute>
           <xsl:attribute name="{@name}">
             <xsl:choose>
               <xsl:when test="@name = 'y'">
                 <xsl:value-of select=". + 4" />
               </xsl:when>
               <xsl:otherwise>
                 <xsl:value-of select="." />
               </xsl:otherwise>
             </xsl:choose>
           </xsl:attribute>
       </xsl:for-each>
         <xsl:call-template name="Plot_Symbol">
           <xsl:with-param name="name" select="./name"></xsl:with-param>
         </xsl:call-template>
     </text>
   </xsl:for-each>
</xsl:template>

<!-- ############################################################################ -->
<!-- ##########################  TEMPLATE CONSONANTS  ########################### -->
<!-- ############################################################################ -->

  <xsl:template name="Consonants">
    <xsl:param name="manner"/>
    <xsl:for-each select="ipa/sound[@type='consonant' and manner=$manner]">
      <xsl:choose>
        <xsl:when test="category='voiceless'">
          <td class="{class/text()}" xsl:use-attribute-sets="no.border.right">
            <xsl:if test="name/unicode != ''">
            <xsl:call-template name="Transcribe">
              <xsl:with-param name="name" select="./name"></xsl:with-param>
            </xsl:call-template>
            </xsl:if>
          </td>
        </xsl:when>
        <xsl:when test="category='voiced'">
          <td class="{class/text()}" xsl:use-attribute-sets="no.border.left">
            <xsl:if test="name/unicode != ''">
            <xsl:call-template name="Transcribe">
              <xsl:with-param name="name" select="./name"></xsl:with-param>
            </xsl:call-template>
            </xsl:if>
          </td>
        </xsl:when>
      </xsl:choose>
    </xsl:for-each>
  </xsl:template>

<!-- ############################################################################ -->
<!-- #######################  TEMPLATE SUPRASEGMENTALS  ######################### -->
<!-- ############################################################################ -->

<xsl:template name="Suprasegmentals">
      <xsl:for-each select="//sound[@type='suprasegmental']"> 
     <tr>
     <xsl:choose>
      <xsl:when test ="example1/unicode != ''">
        <td class="{class/text()}" width="18%" xsl:use-attribute-sets="no.border.right">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./name"></xsl:with-param>
           </xsl:call-template>
       </td>
        <td class="emp" width="45%" xsl:use-attribute-sets="td.text.style">
 <!--   #################   Capitalize First Character   ##################  -->
       <xsl:value-of select="concat(substring(translate(./manner/text(),$lowercase,$uppercase),1,1), substring(./manner/text(),2))"/>
       </td>
        <td class="{class/text()}" type="ex1" width="35%" xsl:use-attribute-sets="no.borders">
          <xsl:call-template name="Transcribe">
            <xsl:with-param name="name" select="./example1"/>
          </xsl:call-template>
       </td>
       </xsl:when>
      <xsl:otherwise>
        <td class="{class/text()}" width="18%" xsl:use-attribute-sets="no.border.right">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./name"></xsl:with-param>
           </xsl:call-template>
       </td>
       <td class="emp" width="80% " colspan="2" xsl:use-attribute-sets="td.text.style">
 <!--   #################   Capitalize First Character   ##################  -->
         <xsl:value-of select="concat(substring(translate(./manner/text(),$lowercase,$uppercase),1,1), substring(./manner/text(),2))"/>
       </td>
      </xsl:otherwise>
      </xsl:choose>
    </tr>
</xsl:for-each>
</xsl:template>

<!-- ############################################################################ -->
<!-- ###########################  TEMPLATE ACCENTS  ############################# -->
<!-- ############################################################################ -->

<xsl:template name="Accents1">
    <xsl:for-each select="//sound[@type='toneoraccent']"> 
     <xsl:if test="type='level'">
     <tr>
       <xsl:choose>
         <xsl:when test ="name2 != ''">
           <td class="{class/text()}" width="22%" xsl:use-attribute-sets="no.border.right">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./name"></xsl:with-param>
           </xsl:call-template>
       </td>
           <td class="{class/text()}" width="22%" xsl:use-attribute-sets="no.borders">
         <xsl:call-template name="Transcribe">
           <xsl:with-param name="name" select="./name2"></xsl:with-param>
         </xsl:call-template>
       </td>
         </xsl:when>
         <xsl:otherwise>
           <td class="{class/text()}" width="30%" colspan="2" xsl:use-attribute-sets="single.symbol">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./name"></xsl:with-param>
           </xsl:call-template>
         </td> 
         </xsl:otherwise>
      </xsl:choose>
       <td class="emp" width="55%" xsl:use-attribute-sets="td.text.style">
 <!--   #################   Capitalize First Character   ##################  -->
       <xsl:value-of select="concat(substring(translate(./manner/text(),$lowercase,$uppercase),1,1), substring(./manner/text(),2))"/>
       </td>
    </tr>
     </xsl:if>
   </xsl:for-each>
</xsl:template>

<xsl:template name="Accents2">
    <xsl:for-each select="//sound[@type='toneoraccent']"> 
     <xsl:if test="type='contour'">
     <tr>
       <xsl:choose>
         <xsl:when test="name2 != ''">
           <td class="{class/text()}" width="22%" xsl:use-attribute-sets="no.border.right">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./name"></xsl:with-param>
           </xsl:call-template>
       </td>
           <td class="{class/text()}" width="22%" xsl:use-attribute-sets="no.borders">
         <xsl:call-template name="Transcribe">
           <xsl:with-param name="name" select="./name2"></xsl:with-param>
         </xsl:call-template>
       </td>              
         </xsl:when>
         <xsl:otherwise>
           <td class="{class/text()}" width="30%" colspan="2" xsl:use-attribute-sets="single.symbol">
             <xsl:call-template name="Transcribe">
               <xsl:with-param name="name" select="./name"></xsl:with-param>
             </xsl:call-template>
           </td>
         </xsl:otherwise>
       </xsl:choose>
       <td class="emp" width="55%" xsl:use-attribute-sets="td.text.style">
 <!--   #################   Capitalize First Character   ##################  -->
       <xsl:value-of select="concat(substring(translate(./manner/text(),$lowercase,$uppercase),1,1), substring(./manner/text(),2))"/>
       </td>
    </tr>
     </xsl:if>
   </xsl:for-each>
</xsl:template>

<!-- ############################################################################ -->
<!-- #########################  TEMPLATE OTHER SYMBOLS  ######################### -->
<!-- ############################################################################ -->

<xsl:template name="OtherSymbols">

    <xsl:for-each select="//sound[@type='other']"> 
     <tr>
     <xsl:choose>
      <xsl:when test ="name2 != ''">
        <td class="{class/text()}" width="10%" xsl:use-attribute-sets="no.border.right">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./name"></xsl:with-param>
           </xsl:call-template>
       </td>
        <td class="{class/text()}" width="10%" xsl:use-attribute-sets="no.borders">
         <xsl:call-template name="Transcribe">
           <xsl:with-param name="name" select="./name2"></xsl:with-param>
         </xsl:call-template>
       </td>
      </xsl:when>
      <xsl:otherwise>
        <td class="{class/text()}" width="20%" colspan="2" xsl:use-attribute-sets="single.symbol">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./name"></xsl:with-param>
           </xsl:call-template>
       </td>
      </xsl:otherwise>
     </xsl:choose>
       <td class="emp" width="80%" xsl:use-attribute-sets="td.text.style">
 <!--   #################   Capitalize First Character   ##################  -->
     <xsl:if test="category != ''">
       <xsl:value-of select="concat(substring(translate(./category/text(),$lowercase,$uppercase),1,1), substring(./category/text(),2))"/>
     </xsl:if>
 <!--   ##########   Capitalize First Character( if category is empty)  ##########  -->
       <xsl:if test="category = ''">
       <xsl:text> </xsl:text>
       <xsl:value-of select="concat(substring(translate(./place/text(),$lowercase,$uppercase),1,1), substring(./place/text(),2))"/>
       </xsl:if>
       <xsl:if test="category != ''">
       <xsl:text> </xsl:text>
       <xsl:value-of select="place/text()"/>
       </xsl:if>
       <xsl:text> </xsl:text>
       <xsl:value-of select="manner/text()"/>
       </td>
    </tr>

   </xsl:for-each>
</xsl:template>

<!-- ############################################################################ -->
<!-- ###########################  TEMPLATE DIACRITICS  ########################## -->
<!-- ############################################################################ -->

<xsl:template name="Diacritics1">
   <xsl:for-each select="//sound[type='diacritic']"> 
    <xsl:if test="position()&lt;18-1">
     <tr>
       <td class="{class/text()}" width="21%" xsl:use-attribute-sets="no.border.right">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./name"></xsl:with-param>
           </xsl:call-template>
       </td>
       <td class="emp" width="49%" xsl:use-attribute-sets="td.text.style">
 <!--   #################   Capitalize First Character   ##################  -->
       <xsl:value-of select="concat(substring(translate(./manner/text(),$lowercase,$uppercase),1,1), substring(./manner/text(),2))"/>
       </td>
       <xsl:choose>
         <xsl:when test="example2 != ''">
           <td class="{class/text()}"  type="ex1" width="15%" xsl:use-attribute-sets="no.borders">
             <xsl:call-template name="Transcribe">
               <xsl:with-param name="name" select="./example1"/>
             </xsl:call-template>
           </td>
           <td class="{class/text()}"  type="ex2" width="15%" xsl:use-attribute-sets="no.border.left">
             <xsl:call-template name="Transcribe">
               <xsl:with-param name="name" select="./example2"/>
             </xsl:call-template>
           </td>
         </xsl:when>
         
        <xsl:otherwise>
          <td class="{class/text()}" type="ex1" width="15%" xsl:use-attribute-sets="single.symbol">
            <xsl:call-template name="Transcribe">
              <xsl:with-param name="name" select="./example1"/>
            </xsl:call-template>
          </td> 
          <td class="emp" width="15%" xsl:use-attribute-sets="single.symbol">
          </td>
         </xsl:otherwise>
       </xsl:choose>
     </tr>
    </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template name="Diacritics2">
    <xsl:for-each select="//sound[type='diacritic']"> 
      <xsl:if test="position()&gt;17-1">
     <tr>
       <td class="{class/text()}" width="21%" xsl:use-attribute-sets="no.border.right">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./name"></xsl:with-param>
           </xsl:call-template>
       </td>
       <td class="emp" width="49%" xsl:use-attribute-sets="td.text.style">
      <xsl:value-of select="concat(substring(translate(./manner/text(),$lowercase,$uppercase),1,1), substring(./manner/text(),2))"/>
       </td>
       <xsl:choose>
         <xsl:when test="example2 != ''">
           <td class="{class/text()}"  type="ex1" width="15%" xsl:use-attribute-sets="no.borders">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./example1"/>
           </xsl:call-template>
         </td>
           <td class="{class/text()}" type="ex2" width="15%" xsl:use-attribute-sets="no.border.left">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./example2"/>
           </xsl:call-template>
         </td>
       </xsl:when>
       <xsl:otherwise> 
         <td class="{class/text()}"  type="ex1" width="15%" xsl:use-attribute-sets="single.symbol">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./example1"/>
           </xsl:call-template>
         </td>
         <td class="emp" width="15%" xsl:use-attribute-sets="single.symbol">
         </td> 
       </xsl:otherwise>
       </xsl:choose>
     </tr>
     </xsl:if>
   </xsl:for-each>
</xsl:template>

<!-- ############################################################################ -->
<!-- ####################  TEMPLATE CONSONANTS NON-PULMONIC  #################### -->
<!-- ############################################################################ -->

<xsl:template name="Clicks">
    <xsl:for-each select="//sound[@type='consonantnp' and manner='click']"> 
    <tbody>
     <tr>
       <td class="{class/text()}" width="25%" xsl:use-attribute-sets="no.border.right">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./name"></xsl:with-param>
           </xsl:call-template>
       </td>
       <td class="emp" width="75%" xsl:use-attribute-sets="td.text.style">
 <!--   #################   Capitalize First Character   ##################  -->
       <xsl:value-of select="concat(substring(translate(./place/text(),$lowercase,$uppercase),1,1), substring(./place/text(),2))"/>
       </td>
    </tr>
    </tbody>
   </xsl:for-each>
</xsl:template>
    
<xsl:template name="Implosives">
    <xsl:for-each select="//sound[@type='consonantnp' and manner='implosive']"> 
     <tr>
       <td class="{class/text()}" width="25%" xsl:use-attribute-sets="no.border.right">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./name"></xsl:with-param>
           </xsl:call-template>
       </td>
       <td class="emp" width="75%" xsl:use-attribute-sets="td.text.style">
 <!--   #################   Capitalize First Character   ##################  -->
       <xsl:value-of select="concat(substring(translate(./place/text(),$lowercase,$uppercase),1,1), substring(./place/text(),2))"/>
       </td>
    </tr>
   </xsl:for-each>
</xsl:template>
     
<xsl:template name="Ejectives">
    <xsl:for-each select="//sound[@type='consonantnp' and manner='ejective']"> 
     <tr>
       <td class="{class/text()}" width="25%" xsl:use-attribute-sets="no.border.right">
           <xsl:call-template name="Transcribe">
             <xsl:with-param name="name" select="./name"></xsl:with-param>
           </xsl:call-template>
       </td>
       <td class="emp" width="75%" xsl:use-attribute-sets="td.text.style">
 <!--   #################   Capitalize First Character   ##################  -->
       <xsl:value-of select="concat(substring(translate(./place/text(),$lowercase,$uppercase),1,1), substring(./place/text(),2))"/>
       </td>
    </tr>
   </xsl:for-each>
</xsl:template>
  
<!-- ############################################################################ -->
<!-- ########################### ADD METADATA TEMPLATE ########################## -->
<!-- ############################################################################ -->

<xsl:template name="Add_metadata">
  <xsl:param name="name"/>
  
  <xsl:if test="class = 'pos'">
  <xsl:attribute name="symbol_name">
    <xsl:value-of select="$name/symbol"/>
  </xsl:attribute>
  
  <xsl:attribute name="phonetic_description">
    <xsl:choose>
      <xsl:when test="@type='vowel'">
        <xsl:value-of select="concat(substring(translate(./manner/text(),$lowercase,$uppercase),1,1), substring(./manner/text(),2))"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="./place/text()"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="./category/text()"/>
        <xsl:text> vowel</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="concat(substring(translate(./category/text(),$lowercase,$uppercase),1,1), substring(./category/text(),2))"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="concat(substring(translate(./place/text(),$lowercase,$uppercase),1,1), substring(./place/text(),2))"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="concat(substring(translate(./manner/text(),$lowercase,$uppercase),1,1), substring(./manner/text(),2))"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:attribute>
  
  <xsl:if test="$name/ucentity != ''">
    <xsl:attribute name="unicode_entity">
      <xsl:value-of select="$name/ucentity"/>
    </xsl:attribute> 
  </xsl:if>
    
  <xsl:if test="$name/ucentity != ''">
    <xsl:attribute name="unicode_hex">
      <xsl:call-template name="remove-leading-zeros">
        <xsl:with-param name="entity" select="$name/ucentity"/>
        <!-- select unicode entity value without leading zeros -->
        <!-- is calling: <xsl:value-of select="concat('&amp;', '#', 'x', $entity, ';')"/> --> 
      </xsl:call-template>
     </xsl:attribute> 
  </xsl:if>
  
  <xsl:if test="$name/cardinal != ''">
    <xsl:attribute name="ipa_number">
      <xsl:value-of select="$name/cardinal"/>
    </xsl:attribute> 
  </xsl:if>   
    
<!--  Audiofiles (WAV) -->
<!--  <xsl:attribute name="data-sound">
    <xsl:choose>
      <xsl:when test="$name/ucentity != ''">
        <xsl:value-of select="concat('./data/audio_samples/wav/', $name/ucentity/text(), '.wav')" />       
      </xsl:when>
      <xsl:when test="./example2 = not(*)">
        <xsl:value-of select="concat('./data/audio_samples/wav/', ./name/ucentity/text(), '.wav')" />         
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="concat('./data/audio_samples/wav/', ./name/ucentity/text(), '_', substring(local-name($name), string-length(local-name($name)) - 1), '.wav')" />        
      </xsl:otherwise>
    </xsl:choose>
  </xsl:attribute>-->
  
<!--  Audiofiles (MP3) -->
  <xsl:attribute name="data-sound">
    <xsl:choose>
      <xsl:when test="$name/ucentity != ''">
        <xsl:value-of select="concat('./data/audio_samples/mp3/', $name/ucentity/text(), '.mp3')" />       
      </xsl:when>
      <xsl:when test="./example2 = not(*)">
        <xsl:value-of select="concat('./data/audio_samples/mp3/', ./name/ucentity/text(), '.mp3')" />         
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="concat('./data/audio_samples/mp3/', ./name/ucentity/text(), '_', substring(local-name($name), string-length(local-name($name)) - 1), '.mp3')" />        
      </xsl:otherwise>
    </xsl:choose>
  </xsl:attribute>  
  
  <xsl:attribute name="unicode">
    <xsl:value-of select="$name/unicode"/>
  </xsl:attribute>
  
  <xsl:attribute name="tex">
    <xsl:choose>
      <xsl:when test="$name/tex[starts-with(text(), '\')]">
        <xsl:value-of select="substring($name/tex/text(), 2)"/> 
      </xsl:when>  
      <xsl:otherwise>
        <xsl:value-of select="$name/tex/text()"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:attribute>
  <!--USE TEX SHORTCUT, IF SHORTCUT DOESNT EXIST (FALLBACK TO TEX) -->
  <xsl:attribute name="tex2">
    <xsl:choose>
      <xsl:when test="$name/tex2 != ''">
        <xsl:choose>
          <xsl:when test="$name/tex2[starts-with(text(), '\')]">
            <xsl:value-of select="substring($name/tex2/text(), 2)"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$name/tex2/text()"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:choose>
          <xsl:when test="$name/tex[starts-with(text(), '\')]">
            <xsl:value-of select="substring($name/tex/text(), 2)"/> 
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$name/tex/text()"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:attribute>
  
  <xsl:attribute name="praat">
    <xsl:choose>
      <xsl:when test="$name/praat[starts-with(text(), '\')]">
        <xsl:value-of select="substring($name/praat/text(), 2)"/> 
      </xsl:when>  
      <xsl:otherwise>
        <xsl:value-of select="$name/praat/text()"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:attribute>
  </xsl:if>
  
</xsl:template>



<xsl:template name="remove-leading-zeros">
  
  <xsl:param name="entity"/>
  <xsl:choose>
    <xsl:when test="starts-with($entity,'0')">
      <xsl:call-template name="remove-leading-zeros">
        <xsl:with-param name="entity"
          select="substring-after($entity,'0')"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="concat('&amp;', '#', 'x', $entity, ';')"/>
    </xsl:otherwise>
  </xsl:choose>
  
</xsl:template>



</xsl:stylesheet>

<!-- ############################################################################ -->
<!-- #################################  END OF FILE   ########################### -->
<!-- ############################################################################ -->